mailr16901 - /trunk/gui/about.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 13, 2012 - 20:36:
Author: bugman
Date: Wed Jun 13 20:36:49 2012
New Revision: 16901

URL: http://svn.gna.org/viewcvs/relax?rev=16901&view=rev
Log:
Improved the debugging drawing for the about GUI elements.


Modified:
    trunk/gui/about.py

Modified: trunk/gui/about.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/gui/about.py?rev=16901&r1=16900&r2=16901&view=diff
==============================================================================
--- trunk/gui/about.py (original)
+++ trunk/gui/about.py Wed Jun 13 20:36:49 2012
@@ -166,18 +166,22 @@
 
         # Debugging lines.
         if status.debug:
+            # Set the font.
+            self.dc.SetFont(wx.Font(8, wx.FONTFAMILY_SCRIPT, wx.NORMAL, 
wx.NORMAL))
+
+            # The virtual size.
+            self.dc.DrawText("Virt size: %sx%s" % (self.virt_x, 
self.virt_y), 2, 2)
+
             # Cross.
             self.dc.DrawLine(0, 0, self.virt_x, self.virt_y)
             self.dc.DrawLine(self.virt_x, 0, 0, self.virt_y)
 
-            # Lines every 200 pixels.
-            num = self.virt_y / 200
-            for i in range(num):
-                pos = i * 200
+            # Lines every 100 pixels.
+            num = self.virt_y / 100
+            for i in range(num+1):
+                pos = i * 100
                 self.dc.DrawLine(0, pos, self.virt_x, pos) 
-                self.dc.SetFont(wx.Font(8, wx.FONTFAMILY_SCRIPT, wx.NORMAL, 
wx.NORMAL))
                 self.dc.DrawText(str(pos), self.virt_x-40, pos-10)
-
 
         # Build the rest of the about widget.
         self.build_widget()




Related Messages


Powered by MHonArc, Updated Wed Jun 13 21:20:02 2012